@@ -55,14 +55,16 @@
 // Bound library includes
 #include <Qt3DAnimation/qskeletonmapping.h>
 #include <Qt3DAnimation/qadditiveclipblend.h>
+#include <Qt3DAnimation/qanimationclipdata.h>
 #include <Qt3DAnimation/qabstractclipanimator.h>
 #include <Qt3DAnimation/qabstractanimationclip.h>
 #include <Qt3DAnimation/qabstractchannelmapping.h>
 #include <Qt3DAnimation/qanimationgroup.h>
-#include <Qt3DAnimation/qclock.h>
+#include <Qt3DAnimation/qchannelmapper.h>
 #include <Qt3DAnimation/qabstractanimation.h>
 #include <Qt3DAnimation/qabstractclipblendnode.h>
 #include <Qt3DAnimation/qanimationcontroller.h>
+#include <Qt3DAnimation/qclock.h>
 #include <Qt3DAnimation/qanimationcallback.h>
 #include <Qt3DAnimation/qmorphinganimation.h>
 #include <Qt3DAnimation/qkeyframe.h>
@@ -107,24 +109,26 @@ enum : int {
     SBK_QT3DANIMATION_QANIMATIONCALLBACK_FLAG_IDX            = 11,
     SBK_QT3DANIMATION_QANIMATIONCALLBACK_IDX                 = 10,
     SBK_QT3DANIMATION_QANIMATIONCLIP_IDX                     = 12,
-    SBK_QT3DANIMATION_QANIMATIONCLIPLOADER_STATUS_IDX        = 14,
-    SBK_QT3DANIMATION_QANIMATIONCLIPLOADER_IDX               = 13,
-    SBK_QT3DANIMATION_QANIMATIONCONTROLLER_IDX               = 15,
-    SBK_QT3DANIMATION_QANIMATIONGROUP_IDX                    = 16,
-    SBK_QT3DANIMATION_QBLENDEDCLIPANIMATOR_IDX               = 17,
-    SBK_QT3DANIMATION_QCLIPANIMATOR_IDX                      = 18,
-    SBK_QT3DANIMATION_QCLOCK_IDX                             = 19,
-    SBK_QT3DANIMATION_QKEYFRAME_INTERPOLATIONTYPE_IDX        = 21,
-    SBK_QT3DANIMATION_QKEYFRAME_IDX                          = 20,
-    SBK_QT3DANIMATION_QKEYFRAMEANIMATION_REPEATMODE_IDX      = 23,
-    SBK_QT3DANIMATION_QKEYFRAMEANIMATION_IDX                 = 22,
-    SBK_QT3DANIMATION_QLERPCLIPBLEND_IDX                     = 24,
-    SBK_QT3DANIMATION_QMORPHTARGET_IDX                       = 25,
-    SBK_QT3DANIMATION_QMORPHINGANIMATION_METHOD_IDX          = 27,
-    SBK_QT3DANIMATION_QMORPHINGANIMATION_IDX                 = 26,
-    SBK_QT3DANIMATION_QSKELETONMAPPING_IDX                   = 28,
-    SBK_QT3DANIMATION_QVERTEXBLENDANIMATION_IDX              = 29,
-    SBK_Qt3DAnimation_IDX_COUNT                              = 30
+    SBK_QT3DANIMATION_QANIMATIONCLIPDATA_IDX                 = 13,
+    SBK_QT3DANIMATION_QANIMATIONCLIPLOADER_STATUS_IDX        = 15,
+    SBK_QT3DANIMATION_QANIMATIONCLIPLOADER_IDX               = 14,
+    SBK_QT3DANIMATION_QANIMATIONCONTROLLER_IDX               = 16,
+    SBK_QT3DANIMATION_QANIMATIONGROUP_IDX                    = 17,
+    SBK_QT3DANIMATION_QBLENDEDCLIPANIMATOR_IDX               = 18,
+    SBK_QT3DANIMATION_QCHANNELMAPPER_IDX                     = 19,
+    SBK_QT3DANIMATION_QCLIPANIMATOR_IDX                      = 20,
+    SBK_QT3DANIMATION_QCLOCK_IDX                             = 21,
+    SBK_QT3DANIMATION_QKEYFRAME_INTERPOLATIONTYPE_IDX        = 23,
+    SBK_QT3DANIMATION_QKEYFRAME_IDX                          = 22,
+    SBK_QT3DANIMATION_QKEYFRAMEANIMATION_REPEATMODE_IDX      = 25,
+    SBK_QT3DANIMATION_QKEYFRAMEANIMATION_IDX                 = 24,
+    SBK_QT3DANIMATION_QLERPCLIPBLEND_IDX                     = 26,
+    SBK_QT3DANIMATION_QMORPHTARGET_IDX                       = 27,
+    SBK_QT3DANIMATION_QMORPHINGANIMATION_METHOD_IDX          = 29,
+    SBK_QT3DANIMATION_QMORPHINGANIMATION_IDX                 = 28,
+    SBK_QT3DANIMATION_QSKELETONMAPPING_IDX                   = 30,
+    SBK_QT3DANIMATION_QVERTEXBLENDANIMATION_IDX              = 31,
+    SBK_Qt3DAnimation_IDX_COUNT                              = 32
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_Qt3DAnimationTypes;
@@ -138,19 +142,20 @@ extern SbkConverter **SbkPySide6_Qt3DAnimationTypeConverters;
 // Converter indices
 enum : int {
     SBK_QT3DANIMATION_QLIST_QT3DCORE_QATTRIBUTEPTR_IDX       = 0, // QList<Qt3DCore::QAttribute* >
-    SBK_QT3DANIMATION_QLIST_QOBJECTPTR_IDX                   = 1, // const QList<QObject* > &
+    SBK_QT3DANIMATION_QLIST_QOBJECTPTR_IDX                   = 1, // QList<QObject* >
     SBK_QT3DANIMATION_QLIST_QBYTEARRAY_IDX                   = 2, // QList<QByteArray >
     SBK_QT3DANIMATION_QLIST_QT3DANIMATION_QANIMATIONGROUPPTR_IDX = 3, // QList<Qt3DAnimation::QAnimationGroup* >
     SBK_QT3DANIMATION_QLIST_QT3DANIMATION_QABSTRACTANIMATIONPTR_IDX = 4, // QList<Qt3DAnimation::QAbstractAnimation* >
     SBK_QT3DANIMATION_QLIST_QT3DCORE_QNODEPTR_IDX            = 5, // QList<Qt3DCore::QNode* >
     SBK_QT3DANIMATION_QLIST_QT3DCORE_QENTITYPTR_IDX          = 6, // QList<Qt3DCore::QEntity* >
-    SBK_QT3DANIMATION_QLIST_QT3DANIMATION_QMORPHTARGETPTR_IDX = 7, // QList<Qt3DAnimation::QMorphTarget* >
-    SBK_QT3DANIMATION_QLIST_FLOAT_IDX                        = 8, // const QList<float > &
-    SBK_QT3DANIMATION_QLIST_QT3DCORE_QTRANSFORMPTR_IDX       = 9, // QList<Qt3DCore::QTransform* >
-    SBK_QT3DANIMATION_QLIST_QVARIANT_IDX                     = 10, // QList<QVariant >
-    SBK_QT3DANIMATION_QLIST_QSTRING_IDX                      = 11, // QList<QString >
-    SBK_QT3DANIMATION_QMAP_QSTRING_QVARIANT_IDX              = 12, // QMap<QString,QVariant >
-    SBK_Qt3DAnimation_CONVERTERS_IDX_COUNT                   = 13
+    SBK_QT3DANIMATION_QLIST_QT3DANIMATION_QABSTRACTCHANNELMAPPINGPTR_IDX = 7, // QList<Qt3DAnimation::QAbstractChannelMapping* >
+    SBK_QT3DANIMATION_QLIST_QT3DANIMATION_QMORPHTARGETPTR_IDX = 8, // QList<Qt3DAnimation::QMorphTarget* >
+    SBK_QT3DANIMATION_QLIST_FLOAT_IDX                        = 9, // QList<float >
+    SBK_QT3DANIMATION_QLIST_QT3DCORE_QTRANSFORMPTR_IDX       = 10, // QList<Qt3DCore::QTransform* >
+    SBK_QT3DANIMATION_QLIST_QVARIANT_IDX                     = 11, // QList<QVariant >
+    SBK_QT3DANIMATION_QLIST_QSTRING_IDX                      = 12, // QList<QString >
+    SBK_QT3DANIMATION_QMAP_QSTRING_QVARIANT_IDX              = 13, // QMap<QString,QVariant >
+    SBK_Qt3DAnimation_CONVERTERS_IDX_COUNT                   = 14
 };
 // Macros for type check
 
@@ -172,11 +177,13 @@ template<> inline PyTypeObject *SbkType< ::Qt3DAnimation::QAnimationAspect >() {
 template<> inline PyTypeObject *SbkType< ::Qt3DAnimation::QAnimationCallback::Flag >() { return SbkPySide6_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONCALLBACK_FLAG_IDX]; }
 template<> inline PyTypeObject *SbkType< ::Qt3DAnimation::QAnimationCallback >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONCALLBACK_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DAnimation::QAnimationClip >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONCLIP_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DAnimation::QAnimationClipData >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONCLIPDATA_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DAnimation::QAnimationClipLoader::Status >() { return SbkPySide6_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONCLIPLOADER_STATUS_IDX]; }
 template<> inline PyTypeObject *SbkType< ::Qt3DAnimation::QAnimationClipLoader >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONCLIPLOADER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DAnimation::QAnimationController >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONCONTROLLER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DAnimation::QAnimationGroup >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONGROUP_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DAnimation::QBlendedClipAnimator >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DAnimationTypes[SBK_QT3DANIMATION_QBLENDEDCLIPANIMATOR_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DAnimation::QChannelMapper >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DAnimationTypes[SBK_QT3DANIMATION_QCHANNELMAPPER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DAnimation::QClipAnimator >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DAnimationTypes[SBK_QT3DANIMATION_QCLIPANIMATOR_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DAnimation::QClock >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DAnimationTypes[SBK_QT3DANIMATION_QCLOCK_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DAnimation::QKeyFrame::InterpolationType >() { return SbkPySide6_Qt3DAnimationTypes[SBK_QT3DANIMATION_QKEYFRAME_INTERPOLATIONTYPE_IDX]; }
