@@ -608,11 +608,11 @@ enum : int {
     SBK_QINTPTR_IDX                                          = 9,
     SBK_QPTRDIFF_IDX                                         = 10,
     SBK_QUINTPTR_IDX                                         = 11,
-    SBK_QTCORE_QLIST_QXMLSTREAMNAMESPACEDECLARATION_IDX      = 12, // const QList<QXmlStreamNamespaceDeclaration > &
+    SBK_QTCORE_QLIST_QXMLSTREAMNAMESPACEDECLARATION_IDX      = 12, // QList<QXmlStreamNamespaceDeclaration >
     SBK_QTCORE_QLIST_QXMLSTREAMENTITYDECLARATION_IDX         = 13, // QList<QXmlStreamEntityDeclaration >
     SBK_QTCORE_QLIST_QXMLSTREAMNOTATIONDECLARATION_IDX       = 14, // QList<QXmlStreamNotationDeclaration >
     SBK_QTCORE_QLIST_QXMLSTREAMATTRIBUTE_IDX                 = 15, // QList<QXmlStreamAttribute >
-    SBK_QTCORE_QLIST_INT_IDX                                 = 16, // QList<int > &&
+    SBK_QTCORE_QLIST_INT_IDX                                 = 16, // QList<int >
     SBK_QTCORE_QPAIR_QSTRING_QSTRING_IDX                     = 17, // QPair<QString,QString >
     SBK_QTCORE_QLIST_QPAIR_QSTRING_QSTRING_IDX               = 18, // QList<QPair< QString,QString > >
     SBK_QTCORE_QLIST_QSTORAGEINFO_IDX                        = 19, // QList<QStorageInfo >
@@ -622,19 +622,19 @@ enum : int {
     SBK_QTCORE_QLIST_QT_DAYOFWEEK_IDX                        = 23, // QList<Qt::DayOfWeek >
     SBK_QTCORE_QLIST_QBYTEARRAY_IDX                          = 24, // QList<QByteArray >
     SBK_QTCORE_QLIST_QTIMEZONE_OFFSETDATA_IDX                = 25, // QList<QTimeZone::OffsetData >
-    SBK_QTCORE_QLIST_QVARIANT_IDX                            = 26, // const QList<QVariant > &
-    SBK_QTCORE_QLIST_QITEMSELECTIONRANGE_IDX                 = 27, // QList<QItemSelectionRange > &&
-    SBK_QTCORE_QLIST_QOBJECTPTR_IDX                          = 28, // const QList<QObject* > &
-    SBK_QTCORE_QLIST_QURL_IDX                                = 29, // const QList<QUrl > &
+    SBK_QTCORE_QLIST_QVARIANT_IDX                            = 26, // QList<QVariant >
+    SBK_QTCORE_QLIST_QITEMSELECTIONRANGE_IDX                 = 27, // QList<QItemSelectionRange >
+    SBK_QTCORE_QLIST_QOBJECTPTR_IDX                          = 28, // QList<QObject* >
+    SBK_QTCORE_QLIST_QURL_IDX                                = 29, // QList<QUrl >
     SBK_QTCORE_QLIST_QPOINTF_IDX                             = 30, // QList<QPointF >
     SBK_QTCORE_QLIST_QFILEINFO_IDX                           = 31, // QList<QFileInfo >
     SBK_QTCORE_QPAIR_QINT64_UNSIGNEDINT_IDX                  = 32, // QPair<qint64,unsigned int >
-    SBK_QTCORE_QLIST_QCOMMANDLINEOPTION_IDX                  = 33, // const QList<QCommandLineOption > &
-    SBK_QTCORE_QHASH_QSTRING_QVARIANT_IDX                    = 34, // const QHash<QString,QVariant > &
-    SBK_QTCORE_QMAP_QSTRING_QVARIANT_IDX                     = 35, // const QMap<QString,QVariant > &
+    SBK_QTCORE_QLIST_QCOMMANDLINEOPTION_IDX                  = 33, // QList<QCommandLineOption >
+    SBK_QTCORE_QHASH_QSTRING_QVARIANT_IDX                    = 34, // QHash<QString,QVariant >
+    SBK_QTCORE_QMAP_QSTRING_QVARIANT_IDX                     = 35, // QMap<QString,QVariant >
     SBK_QTCORE_QLIST_QCBORVALUE_IDX                          = 36, // QList<QCborValue >
     SBK_QTCORE_QMAP_INT_QVARIANT_IDX                         = 37, // QMap<int,QVariant >
-    SBK_QTCORE_QLIST_QPERSISTENTMODELINDEX_IDX               = 38, // const QList<QPersistentModelIndex > &
+    SBK_QTCORE_QLIST_QPERSISTENTMODELINDEX_IDX               = 38, // QList<QPersistentModelIndex >
     SBK_QTCORE_QHASH_INT_QBYTEARRAY_IDX                      = 39, // QHash<int,QByteArray >
     SBK_QTCORE_QLIST_QABSTRACTITEMMODELPTR_IDX               = 40, // QList<QAbstractItemModel* >
     SBK_QTCORE_QLIST_QABSTRACTEVENTDISPATCHER_TIMERINFO_IDX  = 41, // QList<QAbstractEventDispatcher::TimerInfo >
