@@ -527,33 +527,33 @@ extern SbkConverter **SbkPySide6_QtGuiTypeConverters;
 // Converter indices
 enum : int {
     SBK_WID_IDX                                              = 0,
-    SBK_QTGUI_QLIST_QREAL_IDX                                = 1, // const QList<qreal > &
-    SBK_QTGUI_QLIST_QTEXTOPTION_TAB_IDX                      = 2, // const QList<QTextOption::Tab > &
+    SBK_QTGUI_QLIST_QREAL_IDX                                = 1, // QList<qreal >
+    SBK_QTGUI_QLIST_QTEXTOPTION_TAB_IDX                      = 2, // QList<QTextOption::Tab >
     SBK_QTGUI_QLIST_QTEXTLENGTH_IDX                          = 3, // QList<QTextLength >
     SBK_QTGUI_QMAP_INT_QVARIANT_IDX                          = 4, // QMap<int,QVariant >
     SBK_QTGUI_QLIST_QTEXTLAYOUT_FORMATRANGE_IDX              = 5, // QList<QTextLayout::FormatRange >
     SBK_QTGUI_QPAIR_INT_INT_IDX                              = 6, // QPair<int,int >
-    SBK_QTGUI_QLIST_QSTANDARDITEMPTR_IDX                     = 7, // const QList<QStandardItem* > &
+    SBK_QTGUI_QLIST_QSTANDARDITEMPTR_IDX                     = 7, // QList<QStandardItem* >
     SBK_QTGUI_QLIST_QPOINTF_IDX                              = 8, // QList<QPointF >
-    SBK_QTGUI_QLIST_QUINT32_IDX                              = 9, // const QList<quint32 > &
+    SBK_QTGUI_QLIST_QUINT32_IDX                              = 9, // QList<quint32 >
     SBK_QTGUI_QLIST_QFONTDATABASE_WRITINGSYSTEM_IDX          = 10, // QList<QFontDatabase::WritingSystem >
-    SBK_QTGUI_QLIST_QPOINT_IDX                               = 11, // QList<QPoint > &&
+    SBK_QTGUI_QLIST_QPOINT_IDX                               = 11, // QList<QPoint >
     SBK_QTGUI_QLIST_QPOLYGONF_IDX                            = 12, // QList<QPolygonF >
     SBK_QTGUI_QLIST_FLOAT_IDX                                = 13, // QList<float >
     SBK_QTGUI_QLIST_QSIZE_IDX                                = 14, // QList<QSize >
     SBK_QTGUI_STD_PAIR_QREAL_QCOLOR_IDX                      = 15, // std::pair<qreal,QColor >
-    SBK_QTGUI_QLIST_STD_PAIR_QREAL_QCOLOR_IDX                = 16, // const QList<std::pair< qreal,QColor > > &
+    SBK_QTGUI_QLIST_STD_PAIR_QREAL_QCOLOR_IDX                = 16, // QList<std::pair< qreal,QColor > >
     SBK_QTGUI_QLIST_INT_IDX                                  = 17, // QList<int >
     SBK_QTGUI_QLIST_QACCESSIBLEINTERFACEPTR_IDX              = 18, // QList<QAccessibleInterface* >
     SBK_QTGUI_QPAIR_QACCESSIBLEINTERFACEPTR_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX = 19, // QPair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag> >
     SBK_QTGUI_QLIST_QPAIR_QACCESSIBLEINTERFACEPTR_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX = 20, // QList<QPair< QAccessibleInterface*,QFlags<QAccessible::RelationFlag> > >
     SBK_QTGUI_QLIST_UNSIGNEDINT_IDX                          = 21, // QList<unsigned int >
-    SBK_QTGUI_QLIST_QLINE_IDX                                = 22, // const QList<QLine > &
-    SBK_QTGUI_QLIST_QLINEF_IDX                               = 23, // const QList<QLineF > &
-    SBK_QTGUI_QLIST_QRECT_IDX                                = 24, // const QList<QRect > &
-    SBK_QTGUI_QLIST_QRECTF_IDX                               = 25, // const QList<QRectF > &
+    SBK_QTGUI_QLIST_QLINE_IDX                                = 22, // QList<QLine >
+    SBK_QTGUI_QLIST_QLINEF_IDX                               = 23, // QList<QLineF >
+    SBK_QTGUI_QLIST_QRECT_IDX                                = 24, // QList<QRect >
+    SBK_QTGUI_QLIST_QRECTF_IDX                               = 25, // QList<QRectF >
     SBK_QTGUI_QLIST_QKEYSEQUENCE_IDX                         = 26, // QList<QKeySequence >
-    SBK_QTGUI_QLIST_QOBJECTPTR_IDX                           = 27, // const QList<QObject* > &
+    SBK_QTGUI_QLIST_QOBJECTPTR_IDX                           = 27, // QList<QObject* >
     SBK_QTGUI_QLIST_QBYTEARRAY_IDX                           = 28, // QList<QByteArray >
     SBK_QTGUI_QLIST_QUNDOSTACKPTR_IDX                        = 29, // QList<QUndoStack* >
     SBK_QTGUI_QLIST_QTEXTFRAMEPTR_IDX                        = 30, // QList<QTextFrame* >
@@ -564,10 +564,10 @@ enum : int {
     SBK_QTGUI_QSET_QBYTEARRAY_IDX                            = 35, // QSet<QByteArray >
     SBK_QTGUI_QLIST_CONSTQINPUTDEVICEPTR_IDX                 = 36, // QList<const QInputDevice* >
     SBK_QTGUI_QLIST_QACTIONPTR_IDX                           = 37, // QList<QAction* >
-    SBK_QTGUI_QLIST_QINPUTMETHODEVENT_ATTRIBUTE_IDX          = 38, // const QList<QInputMethodEvent::Attribute > &
-    SBK_QTGUI_QLIST_QEVENTPOINT_IDX                          = 39, // const QList<QEventPoint > &
+    SBK_QTGUI_QLIST_QINPUTMETHODEVENT_ATTRIBUTE_IDX          = 38, // QList<QInputMethodEvent::Attribute >
+    SBK_QTGUI_QLIST_QEVENTPOINT_IDX                          = 39, // QList<QEventPoint >
     SBK_QTGUI_QLIST_QWINDOWPTR_IDX                           = 40, // QList<QWindow* >
-    SBK_QTGUI_QLIST_QPERSISTENTMODELINDEX_IDX                = 41, // const QList<QPersistentModelIndex > &
+    SBK_QTGUI_QLIST_QPERSISTENTMODELINDEX_IDX                = 41, // QList<QPersistentModelIndex >
     SBK_QTGUI_QHASH_INT_QBYTEARRAY_IDX                       = 42, // QHash<int,QByteArray >
     SBK_QTGUI_QLIST_QVARIANT_IDX                             = 43, // QList<QVariant >
     SBK_QTGUI_QLIST_QSTRING_IDX                              = 44, // QList<QString >
