@@ -151,66 +151,69 @@ enum : int {
     SBK_QNETWORKADDRESSENTRY_IDX                             = 47,
     SBK_QNETWORKCACHEMETADATA_IDX                            = 49,
     SBK_QNETWORKCOOKIE_RAWFORM_IDX                           = 51,
+    SBK_QNETWORKCOOKIE_SAMESITE_IDX                          = 52,
     SBK_QNETWORKCOOKIE_IDX                                   = 50,
-    SBK_QNETWORKCOOKIEJAR_IDX                                = 52,
-    SBK_QNETWORKDATAGRAM_IDX                                 = 53,
-    SBK_QNETWORKDISKCACHE_IDX                                = 54,
-    SBK_QNETWORKINTERFACE_INTERFACEFLAG_IDX                  = 56,
+    SBK_QNETWORKCOOKIEJAR_IDX                                = 53,
+    SBK_QNETWORKDATAGRAM_IDX                                 = 54,
+    SBK_QNETWORKDISKCACHE_IDX                                = 55,
+    SBK_QNETWORKINTERFACE_INTERFACEFLAG_IDX                  = 57,
     SBK_QFLAGS_QNETWORKINTERFACE_INTERFACEFLAG_IDX           = 26,
-    SBK_QNETWORKINTERFACE_INTERFACETYPE_IDX                  = 57,
-    SBK_QNETWORKINTERFACE_IDX                                = 55,
-    SBK_QNETWORKPROXY_PROXYTYPE_IDX                          = 60,
-    SBK_QNETWORKPROXY_CAPABILITY_IDX                         = 59,
+    SBK_QNETWORKINTERFACE_INTERFACETYPE_IDX                  = 58,
+    SBK_QNETWORKINTERFACE_IDX                                = 56,
+    SBK_QNETWORKPROXY_PROXYTYPE_IDX                          = 61,
+    SBK_QNETWORKPROXY_CAPABILITY_IDX                         = 60,
     SBK_QFLAGS_QNETWORKPROXY_CAPABILITY_IDX                  = 27,
-    SBK_QNETWORKPROXY_IDX                                    = 58,
-    SBK_QNETWORKPROXYFACTORY_IDX                             = 61,
-    SBK_QNETWORKPROXYQUERY_QUERYTYPE_IDX                     = 63,
-    SBK_QNETWORKPROXYQUERY_IDX                               = 62,
-    SBK_QNETWORKREPLY_NETWORKERROR_IDX                       = 65,
-    SBK_QNETWORKREPLY_IDX                                    = 64,
-    SBK_QNETWORKREQUEST_KNOWNHEADERS_IDX                     = 69,
-    SBK_QNETWORKREQUEST_ATTRIBUTE_IDX                        = 67,
-    SBK_QNETWORKREQUEST_CACHELOADCONTROL_IDX                 = 68,
-    SBK_QNETWORKREQUEST_LOADCONTROL_IDX                      = 70,
-    SBK_QNETWORKREQUEST_PRIORITY_IDX                         = 71,
-    SBK_QNETWORKREQUEST_REDIRECTPOLICY_IDX                   = 72,
-    SBK_QNETWORKREQUEST_TRANSFERTIMEOUTCONSTANT_IDX          = 73,
-    SBK_QNETWORKREQUEST_IDX                                  = 66,
-    SBK_QOCSPRESPONSE_IDX                                    = 75,
-    SBK_QtNetworkQPASSWORDDIGESTOR_IDX                       = 77,
-    SBK_QSSL_KEYTYPE_IDX                                     = 84,
-    SBK_QSSL_ENCODINGFORMAT_IDX                              = 82,
-    SBK_QSSL_KEYALGORITHM_IDX                                = 83,
-    SBK_QSSL_ALTERNATIVENAMEENTRYTYPE_IDX                    = 81,
-    SBK_QSSL_SSLPROTOCOL_IDX                                 = 86,
-    SBK_QSSL_SSLOPTION_IDX                                   = 85,
+    SBK_QNETWORKPROXY_IDX                                    = 59,
+    SBK_QNETWORKPROXYFACTORY_IDX                             = 62,
+    SBK_QNETWORKPROXYQUERY_QUERYTYPE_IDX                     = 64,
+    SBK_QNETWORKPROXYQUERY_IDX                               = 63,
+    SBK_QNETWORKREPLY_NETWORKERROR_IDX                       = 66,
+    SBK_QNETWORKREPLY_IDX                                    = 65,
+    SBK_QNETWORKREQUEST_KNOWNHEADERS_IDX                     = 70,
+    SBK_QNETWORKREQUEST_ATTRIBUTE_IDX                        = 68,
+    SBK_QNETWORKREQUEST_CACHELOADCONTROL_IDX                 = 69,
+    SBK_QNETWORKREQUEST_LOADCONTROL_IDX                      = 71,
+    SBK_QNETWORKREQUEST_PRIORITY_IDX                         = 72,
+    SBK_QNETWORKREQUEST_REDIRECTPOLICY_IDX                   = 73,
+    SBK_QNETWORKREQUEST_TRANSFERTIMEOUTCONSTANT_IDX          = 74,
+    SBK_QNETWORKREQUEST_IDX                                  = 67,
+    SBK_QOCSPRESPONSE_IDX                                    = 76,
+    SBK_QtNetworkQPASSWORDDIGESTOR_IDX                       = 78,
+    SBK_QSSL_KEYTYPE_IDX                                     = 86,
+    SBK_QSSL_ENCODINGFORMAT_IDX                              = 83,
+    SBK_QSSL_KEYALGORITHM_IDX                                = 85,
+    SBK_QSSL_ALTERNATIVENAMEENTRYTYPE_IDX                    = 82,
+    SBK_QSSL_SSLPROTOCOL_IDX                                 = 88,
+    SBK_QSSL_SSLOPTION_IDX                                   = 87,
     SBK_QFLAGS_QSSL_SSLOPTION_IDX                            = 28,
-    SBK_QSSL_ALERTLEVEL_IDX                                  = 79,
-    SBK_QSSL_ALERTTYPE_IDX                                   = 80,
-    SBK_QtNetworkQSSL_IDX                                    = 78,
-    SBK_QSSLCERTIFICATE_SUBJECTINFO_IDX                      = 89,
-    SBK_QSSLCERTIFICATE_PATTERNSYNTAX_IDX                    = 88,
-    SBK_QSSLCERTIFICATE_IDX                                  = 87,
-    SBK_QSSLCERTIFICATEEXTENSION_IDX                         = 90,
-    SBK_QSSLCIPHER_IDX                                       = 91,
-    SBK_QSSLCONFIGURATION_NEXTPROTOCOLNEGOTIATIONSTATUS_IDX  = 93,
-    SBK_QSSLCONFIGURATION_IDX                                = 92,
-    SBK_QSSLDIFFIEHELLMANPARAMETERS_ERROR_IDX                = 95,
-    SBK_QSSLDIFFIEHELLMANPARAMETERS_IDX                      = 94,
-    SBK_QSSLERROR_SSLERROR_IDX                               = 97,
-    SBK_QSSLERROR_IDX                                        = 96,
-    SBK_QSSLKEY_IDX                                          = 98,
-    SBK_QSSLPRESHAREDKEYAUTHENTICATOR_IDX                    = 99,
-    SBK_QSSLSOCKET_SSLMODE_IDX                               = 102,
-    SBK_QSSLSOCKET_PEERVERIFYMODE_IDX                        = 101,
-    SBK_QSSLSOCKET_IDX                                       = 100,
-    SBK_QTCPSERVER_IDX                                       = 103,
-    SBK_QTCPSOCKET_IDX                                       = 104,
-    SBK_QUDPSOCKET_IDX                                       = 105,
+    SBK_QSSL_ALERTLEVEL_IDX                                  = 80,
+    SBK_QSSL_ALERTTYPE_IDX                                   = 81,
+    SBK_QSSL_IMPLEMENTEDCLASS_IDX                            = 84,
+    SBK_QSSL_SUPPORTEDFEATURE_IDX                            = 89,
+    SBK_QtNetworkQSSL_IDX                                    = 79,
+    SBK_QSSLCERTIFICATE_SUBJECTINFO_IDX                      = 92,
+    SBK_QSSLCERTIFICATE_PATTERNSYNTAX_IDX                    = 91,
+    SBK_QSSLCERTIFICATE_IDX                                  = 90,
+    SBK_QSSLCERTIFICATEEXTENSION_IDX                         = 93,
+    SBK_QSSLCIPHER_IDX                                       = 94,
+    SBK_QSSLCONFIGURATION_NEXTPROTOCOLNEGOTIATIONSTATUS_IDX  = 96,
+    SBK_QSSLCONFIGURATION_IDX                                = 95,
+    SBK_QSSLDIFFIEHELLMANPARAMETERS_ERROR_IDX                = 98,
+    SBK_QSSLDIFFIEHELLMANPARAMETERS_IDX                      = 97,
+    SBK_QSSLERROR_SSLERROR_IDX                               = 100,
+    SBK_QSSLERROR_IDX                                        = 99,
+    SBK_QSSLKEY_IDX                                          = 101,
+    SBK_QSSLPRESHAREDKEYAUTHENTICATOR_IDX                    = 102,
+    SBK_QSSLSOCKET_SSLMODE_IDX                               = 105,
+    SBK_QSSLSOCKET_PEERVERIFYMODE_IDX                        = 104,
+    SBK_QSSLSOCKET_IDX                                       = 103,
+    SBK_QTCPSERVER_IDX                                       = 106,
+    SBK_QTCPSOCKET_IDX                                       = 107,
+    SBK_QUDPSOCKET_IDX                                       = 108,
     SBK_QDTLSERROR_IDX                                       = 20,
-    SBK_QOCSPCERTIFICATESTATUS_IDX                           = 74,
-    SBK_QOCSPREVOCATIONREASON_IDX                            = 76,
-    SBK_QtNetwork_IDX_COUNT                                  = 106
+    SBK_QOCSPCERTIFICATESTATUS_IDX                           = 75,
+    SBK_QOCSPREVOCATIONREASON_IDX                            = 77,
+    SBK_QtNetwork_IDX_COUNT                                  = 109
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_QtNetworkTypes;
@@ -223,7 +226,7 @@ extern SbkConverter **SbkPySide6_QtNetworkTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTNETWORK_QLIST_QSSLCERTIFICATE_IDX                  = 0, // const QList<QSslCertificate > &
+    SBK_QTNETWORK_QLIST_QSSLCERTIFICATE_IDX                  = 0, // QList<QSslCertificate >
     SBK_QTNETWORK_QLIST_QBYTEARRAY_IDX                       = 1, // QList<QByteArray >
     SBK_QTNETWORK_QMAP_QBYTEARRAY_QVARIANT_IDX               = 2, // QMap<QByteArray,QVariant >
     SBK_QTNETWORK_QLIST_QSSLCIPHER_IDX                       = 3, // QList<QSslCipher >
@@ -234,24 +237,27 @@ enum : int {
     SBK_QTNETWORK_QHASH_QNETWORKREQUEST_ATTRIBUTE_QVARIANT_IDX = 8, // QHash<QNetworkRequest::Attribute,QVariant >
     SBK_QTNETWORK_STD_PAIR_QBYTEARRAY_QBYTEARRAY_IDX         = 9, // std::pair<QByteArray,QByteArray >
     SBK_QTNETWORK_QLIST_STD_PAIR_QBYTEARRAY_QBYTEARRAY_IDX   = 10, // QList<std::pair< QByteArray,QByteArray > >
-    SBK_QTNETWORK_QPAIR_QHOSTADDRESS_INT_IDX                 = 11, // const QPair<QHostAddress,int > &
+    SBK_QTNETWORK_QPAIR_QHOSTADDRESS_INT_IDX                 = 11, // QPair<QHostAddress,int >
     SBK_QTNETWORK_QHASH_QSTRING_QVARIANT_IDX                 = 12, // QHash<QString,QVariant >
-    SBK_QTNETWORK_QLIST_QOBJECTPTR_IDX                       = 13, // const QList<QObject* > &
+    SBK_QTNETWORK_QLIST_QOBJECTPTR_IDX                       = 13, // QList<QObject* >
     SBK_QTNETWORK_QLIST_QNETWORKCOOKIE_IDX                   = 14, // QList<QNetworkCookie >
-    SBK_QTNETWORK_QLIST_QHSTSPOLICY_IDX                      = 15, // const QList<QHstsPolicy > &
-    SBK_QTNETWORK_QLIST_QSSLERROR_IDX                        = 16, // const QList<QSslError > &
+    SBK_QTNETWORK_QLIST_QHSTSPOLICY_IDX                      = 15, // QList<QHstsPolicy >
+    SBK_QTNETWORK_QLIST_QSSLERROR_IDX                        = 16, // QList<QSslError >
     SBK_QTNETWORK_QLIST_QDNSDOMAINNAMERECORD_IDX             = 17, // QList<QDnsDomainNameRecord >
     SBK_QTNETWORK_QLIST_QDNSHOSTADDRESSRECORD_IDX            = 18, // QList<QDnsHostAddressRecord >
     SBK_QTNETWORK_QLIST_QDNSMAILEXCHANGERECORD_IDX           = 19, // QList<QDnsMailExchangeRecord >
     SBK_QTNETWORK_QLIST_QDNSSERVICERECORD_IDX                = 20, // QList<QDnsServiceRecord >
     SBK_QTNETWORK_QLIST_QDNSTEXTRECORD_IDX                   = 21, // QList<QDnsTextRecord >
-    SBK_QTNETWORK_QLIST_QOCSPRESPONSE_IDX                    = 22, // QList<QOcspResponse >
-    SBK_QTNETWORK_QLIST_QSSLCERTIFICATEEXTENSION_IDX         = 23, // QList<QSslCertificateExtension >
-    SBK_QTNETWORK_QMULTIMAP_QSSL_ALTERNATIVENAMEENTRYTYPE_QSTRING_IDX = 24, // QMultiMap<QSsl::AlternativeNameEntryType,QString >
-    SBK_QTNETWORK_QLIST_QVARIANT_IDX                         = 25, // QList<QVariant >
-    SBK_QTNETWORK_QLIST_QSTRING_IDX                          = 26, // QList<QString >
-    SBK_QTNETWORK_QMAP_QSTRING_QVARIANT_IDX                  = 27, // QMap<QString,QVariant >
-    SBK_QtNetwork_CONVERTERS_IDX_COUNT                       = 28
+    SBK_QTNETWORK_QLIST_QSTRING_IDX                          = 22, // QList<QString >
+    SBK_QTNETWORK_QLIST_QSSL_IMPLEMENTEDCLASS_IDX            = 23, // QList<QSsl::ImplementedClass >
+    SBK_QTNETWORK_QLIST_QOCSPRESPONSE_IDX                    = 24, // QList<QOcspResponse >
+    SBK_QTNETWORK_QLIST_QSSL_SUPPORTEDFEATURE_IDX            = 25, // QList<QSsl::SupportedFeature >
+    SBK_QTNETWORK_QLIST_QSSL_SSLPROTOCOL_IDX                 = 26, // QList<QSsl::SslProtocol >
+    SBK_QTNETWORK_QLIST_QSSLCERTIFICATEEXTENSION_IDX         = 27, // QList<QSslCertificateExtension >
+    SBK_QTNETWORK_QMULTIMAP_QSSL_ALTERNATIVENAMEENTRYTYPE_QSTRING_IDX = 28, // QMultiMap<QSsl::AlternativeNameEntryType,QString >
+    SBK_QTNETWORK_QLIST_QVARIANT_IDX                         = 29, // QList<QVariant >
+    SBK_QTNETWORK_QMAP_QSTRING_QVARIANT_IDX                  = 30, // QMap<QString,QVariant >
+    SBK_QtNetwork_CONVERTERS_IDX_COUNT                       = 31
 };
 // Macros for type check
 
@@ -311,6 +317,7 @@ template<> inline PyTypeObject *SbkType< ::QNetworkAddressEntry::DnsEligibilityS
 template<> inline PyTypeObject *SbkType< ::QNetworkAddressEntry >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QNETWORKADDRESSENTRY_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QNetworkCacheMetaData >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QNETWORKCACHEMETADATA_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QNetworkCookie::RawForm >() { return SbkPySide6_QtNetworkTypes[SBK_QNETWORKCOOKIE_RAWFORM_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QNetworkCookie::SameSite >() { return SbkPySide6_QtNetworkTypes[SBK_QNETWORKCOOKIE_SAMESITE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QNetworkCookie >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QNETWORKCOOKIE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QNetworkCookieJar >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QNETWORKCOOKIEJAR_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QNetworkDatagram >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QNETWORKDATAGRAM_IDX]); }
@@ -346,6 +353,8 @@ template<> inline PyTypeObject *SbkType< ::QSsl::SslOption >() { return SbkPySid
 template<> inline PyTypeObject *SbkType< ::QFlags<QSsl::SslOption> >() { return SbkPySide6_QtNetworkTypes[SBK_QFLAGS_QSSL_SSLOPTION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSsl::AlertLevel >() { return SbkPySide6_QtNetworkTypes[SBK_QSSL_ALERTLEVEL_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSsl::AlertType >() { return SbkPySide6_QtNetworkTypes[SBK_QSSL_ALERTTYPE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QSsl::ImplementedClass >() { return SbkPySide6_QtNetworkTypes[SBK_QSSL_IMPLEMENTEDCLASS_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QSsl::SupportedFeature >() { return SbkPySide6_QtNetworkTypes[SBK_QSSL_SUPPORTEDFEATURE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSslCertificate::SubjectInfo >() { return SbkPySide6_QtNetworkTypes[SBK_QSSLCERTIFICATE_SUBJECTINFO_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSslCertificate::PatternSyntax >() { return SbkPySide6_QtNetworkTypes[SBK_QSSLCERTIFICATE_PATTERNSYNTAX_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSslCertificate >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QSSLCERTIFICATE_IDX]); }
