@@ -165,12 +165,12 @@ extern SbkConverter **SbkPySide6_QtQuickTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTQUICK_QLIST_QOBJECTPTR_IDX                         = 0, // const QList<QObject* > &
+    SBK_QTQUICK_QLIST_QOBJECTPTR_IDX                         = 0, // QList<QObject* >
     SBK_QTQUICK_QLIST_QBYTEARRAY_IDX                         = 1, // QList<QByteArray >
     SBK_QTQUICK_QLIST_QQUICKITEMPTR_IDX                      = 2, // QList<QQuickItem* >
-    SBK_QTQUICK_QLIST_INT_IDX                                = 3, // const QList<int > &
+    SBK_QTQUICK_QLIST_INT_IDX                                = 3, // QList<int >
     SBK_QTQUICK_QLIST_QQMLERROR_IDX                          = 4, // QList<QQmlError >
-    SBK_QTQUICK_QMAP_QSTRING_QVARIANT_IDX                    = 5, // const QMap<QString,QVariant > &
+    SBK_QTQUICK_QMAP_QSTRING_QVARIANT_IDX                    = 5, // QMap<QString,QVariant >
     SBK_QTQUICK_QLIST_QVARIANT_IDX                           = 6, // QList<QVariant >
     SBK_QTQUICK_QLIST_QSTRING_IDX                            = 7, // QList<QString >
     SBK_QtQuick_CONVERTERS_IDX_COUNT                         = 8
